import os
import random
import requests

def randomize(base_url):
    # Fetch both lists
    yt_list = requests.get(f"{base_url}musiclist.txt").text.split("\n")
    other_list = requests.get(f"{base_url}other-providers.txt").text.split("\n")
    
    # HTML template
    html = """<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <link href="https://fonts.googleapis.com/css2?family=JetBrains+Mono:wght@400;700&display=swap" rel="stylesheet">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Halhadus' Music List</title>
    <link rel="icon" type="image/png" href="assets/favicon.png">
    <meta name="description" content="Halhadus' Music List">
    <meta property="og:title" content="Halhadus' Music List">
    <meta property="og:description" content="Halhadus' Music List">
    <meta property="og:image" content="assets/favicon.png">
    <meta property="og:url" content="https://halhadus.rocks/musiclist.html">
    <style>
        .music-card {
            background: #2a2a2a;
            border-radius: 8px;
            padding: 15px;
            margin: 15px 0;
            transition: transform 0.2s;
            border: 1px solid #333333;
        }
        .play-button {
            background: #333333;
            border: 1px solid #444444;
            border-radius: 5px;
            color: #ffffff;
            padding: 6px 12px;
            cursor: pointer;
            margin-left: 15px;
            font-family: 'JetBrains Mono', monospace;
            font-size: 0.9em;
        }
        .source-banner {
            background: #2a2a2a;
            padding: 12px;
            border-radius: 8px;
            margin: 20px 0;
            text-align: center;
            border: 1px solid #333333;
        }
    </style>
</head>
<body style="background-color: #1f1f1f; color: #ffffff; font-family: 'JetBrains Mono', monospace;">
    <div style="max-width: 800px; margin: 0 auto; padding: 20px;">
        <h1>Music List</h1>

        <!-- Source Banner -->
        <div class="source-banner">
            <a href="https://git.halhadus.rocks/Halhadus/my-music-list"
               style="color: #ffffff; text-decoration: none;">
                [ 📜 Source Code & History ]
            </a>
        </div>

        <!-- Control Buttons -->
        <div style="margin-bottom: 30px; display: flex; gap: 10px;">
            <button onclick="window.location.href = 'https://halhadus.rocks/index.html'"
                    class="play-button">
                ← Main Page
            </button>
            <button onclick="openRandomMusicCard()" class="play-button">
                Random Track →
            </button>
        </div>"""

    total_count = 0
    sections = [
        ("YouTube Music", yt_list, True),
        ("Other Providers", other_list, False)
    ]

    # Process both sections
    for section_name, musiclist, show_thumb in sections:
        html += f"\n<h2 style='margin-top: 40px;'>{section_name}</h2>"
        section_count = 0
        random.shuffle(musiclist)

        for music in musiclist:
            try:
                music = music.strip()
                if not music:
                    continue

                # Parse entry
                if section_name == "YouTube Music":
                    title, vid, platform = music.split(" --- ")
                    yt_url = f"https://{'music.youtube.com' if platform == 'YTM' else 'www.youtube.com'}/watch?v={vid}"
                    btn_text = platform
                else:
                    display_name, url, _ = music.split(" --- ")
                    yt_url = url
                    btn_text = "Other"

                # Generate HTML
                html += f"""
                <div class="music-card" data-url="{yt_url}">
                    <div style="margin-bottom: 10px; display: flex; align-items: center;">
                        <span style="color: #888; margin-right: 10px;">#{total_count+1}</span>
                        <span style="flex-grow: 1;">{display_name if section_name == "Other Providers" else title}</span>
                        <button onclick="window.open('{yt_url}')" class="play-button">
                            {btn_text} →
                        </button>
                    </div>"""

                if show_thumb and section_name == "YouTube Music":
                    html += f"""
                    <img src="https://img.youtube.com/vi/{vid}/hqdefault.jpg"
                         style="border-radius: 5px; margin-top: 12px; max-width: 280px; border: 1px solid #333333;"
                         alt="Cover Art"
                         onerror="this.style.display='none'">"""

                html += "\n</div>"
                total_count += 1
                section_count += 1

            except Exception as e:
                print(f"Error processing: {music} - {str(e)}")

    # Footer
    html += f"""
        <div style="margin-top: 40px; text-align: center; color: #666;">
            <div style="margin-bottom: 15px;">
                Total Tracks: {total_count}
            </div>
        </div>
    </div>
    <script>
        function openRandomMusicCard() {{
            const cards = document.querySelectorAll('.music-card[data-url]');
            if (!cards.length) return alert('No music found!');
            const randomCard = cards[Math.floor(Math.random() * cards.length)];
            window.open(randomCard.dataset.url);
        }}
    </script>
</body>
</html>"""

    return html
